@@ -304,6 +304,7 @@ class HttpRequest:
         'list',
         'locale',  # RFC 4646
         'macaddr',
+        'natural_number',  # Positive integers including zero
         'object',
         'regex',
         'string',
@@ -538,6 +539,9 @@ class HttpRequest:
         if data_type == HttpRequest.ArgumentDataType.integer:
             return cast.string_to_integer(argument_value, strict=False)
 
+        if data_type == HttpRequest.ArgumentDataType.natural_number:
+            return cast.string_to_natural_number(argument_value, strict=False)
+
         if data_type == HttpRequest.ArgumentDataType.ipv4:
             return cast.string_to_ipv4(argument_value, strict=False)
 
@@ -837,9 +841,10 @@ class HttpMethodSpec:
     PARAMETER_TYPE_REGEX_PATTERNS = {
         HttpRequest.ArgumentDataType.integer: regex.REGEX_PATTERN_INTEGER,
         HttpRequest.ArgumentDataType.ipv4: regex.REGEX_PATTERN_IPV4,
-        HttpRequest.ArgumentDataType.uuid: regex.REGEX_PATTERN_UUID,
-        HttpRequest.ArgumentDataType.string: r'[^/]+',
         HttpRequest.ArgumentDataType.list: r'(([^/,]+,)*|[^/,]+)+',
+        HttpRequest.ArgumentDataType.natural_number: regex.REGEX_PATTERN_NATURAL_NUMBER,
+        HttpRequest.ArgumentDataType.string: r'[^/]+',
+        HttpRequest.ArgumentDataType.uuid: regex.REGEX_PATTERN_UUID,
     }
 
     def __init__(
